/*
  AntiRight
  (c) 2002-2005 Jeffrey Bedard
  antiright@gmail.com
 
  This file is part of AntiRight.

  AntiRight is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  AntiRight is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with AntiRight; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include "library.h"

gpointer
xmalloc(size_t size)
{
  gpointer pointer;
  pointer=g_malloc(size);
  assert(pointer); /* Ensure that the allocation was
			      successful.  */
  return(pointer);
}

void
rand_seed()
{
	srand((unsigned int)time(NULL));
}

int
rand_ranged(int start, int finish)
{
	return rand()%(finish-start)+start;
}


